@@ -8,7 +8,7 @@
  *
  * @copyright &copy; 1999-2007 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: load_prefs.php 12127 2007-01-13 20:07:24Z kink $
+ * @version $Id: load_prefs.php 12681 2007-09-06 22:48:42Z pdontthink $
  * @package squirrelmail
  */
 
@@ -264,9 +264,7 @@ $use_javascript_addr_book = getPref($data_dir, $username, 'use_javascript_addr_b
 
 $search_memory = getPref($data_dir, $username, 'search_memory', 0);
 
-$forward_cc = getPref($data_dir, $username, 'forward_cc', 0);
-
-$mailbox_select_style = getPref($data_dir, $username, 'mailbox_select_style', 0);
+$mailbox_select_style = getPref($data_dir, $username, 'mailbox_select_style', 1);
 
 /* Allow user to customize, and display the full date, instead of day, or time based
    on time distance from date of message */
@@ -279,4 +277,3 @@ $truncate_subject = getPref($data_dir, $username, 'truncate_subject', 50);
 
 do_hook('loading_prefs');
 
-?>
\ No newline at end of file
