@@ -22,7 +22,7 @@
  * This was tested with IE5.0 - but I hear Netscape works well,
  * too (with a plugin).
  *
- * @version $Id: setup.php 10633 2006-02-03 22:27:56Z jervfors $
+ * @version $Id: setup.php 12538 2007-07-14 19:04:00Z kink $
  * @package plugins
  * @subpackage new_mail
  */
@@ -157,7 +157,7 @@ function newmail_set_loadinfo() {
 function newmail_plugin() {
     global $username, $key, $imapServerAddress, $imapPort,
         $newmail_media, $newmail_enable, $newmail_popup,
-        $newmail_recent, $newmail_changetitle, $imapConnection, $PHP_SELF;
+        $newmail_recent, $newmail_changetitle, $imapConnection;
 
     include_once(SM_PATH . 'functions/display_messages.php');
 
@@ -256,4 +256,3 @@ function newmail_plugin() {
         }
     }
 }
-?>
\ No newline at end of file
