@@ -5,7 +5,7 @@
  *
  * @copyright &copy; 2003-2007 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: configtest.php 12159 2007-01-20 07:01:43Z pdontthink $
+ * @version $Id: configtest.php 12657 2007-08-31 23:20:33Z pdontthink $
  * @package squirrelmail
  * @subpackage config
  */
@@ -25,6 +25,9 @@ function do_err($str, $exit = TRUE) {
 }
 
 ob_implicit_flush();
+/** This is the configtest page */
+define('PAGE_NAME', 'configtest');
+
 /** @ignore */
 define('SM_PATH', '../');
 
@@ -80,12 +83,64 @@ echo "<p><table>\n<tr><td>SquirrelMail version:</td><td><b>" . $version . "</b><
 
 echo "Checking PHP configuration...<br />\n";
 
-if(!check_php_version(4,0,6)) {
-    do_err('Insufficient PHP version: '. PHP_VERSION . '! Minimum required: 4.0.6');
+if(!check_php_version(4,1,0)) {
+    do_err('Insufficient PHP version: '. PHP_VERSION . '! Minimum required: 4.1.0');
 }
 
 echo $IND . 'PHP version ' . PHP_VERSION . " OK.<br />\n";
 
+echo $IND . 'display_errors: ' . ini_get('display_errors') . "<br />\n";
+
+echo $IND . 'error_reporting: ' . ini_get('error_reporting') . "<br />\n";
+
+
+/* variables_order check */
+
+// FIXME(?): Hmm, how do we distinguish between when an ini setting is
+//           not available (ini_set() returns empty string) and when
+//           the administrator set the value to an empty string?  The
+//           latter is sure to be highly rare, so for now, just assume
+//           that empty value means the setting isn't even available
+//           (could also check PHP version when this setting was implemented)
+//           although, we'll also warn the user if it is empty, with
+//           a non-fatal error
+$variables_order = strtoupper(ini_get('variables_order'));
+if (empty($variables_order))
+    do_err('Your variables_order setting seems to be empty.  Make sure it is undefined in any PHP ini files, .htaccess files, etc. and not specifically set to an empty value or SquirrelMail may not function correctly', false);
+else if (strpos($variables_order, 'G') === FALSE
+ || strpos($variables_order, 'P') === FALSE
+ || strpos($variables_order, 'C') === FALSE
+ || strpos($variables_order, 'S') === FALSE) {
+    do_err('Your variables_order setting is insufficient for SquirrelMail to function.  It needs at least "GPCS", but you have it set to "' . htmlspecialchars($variables_order) . '"', true);
+} else {
+    echo $IND . "variables_order OK: $variables_order.<br />\n";
+}
+
+
+/* gpc_order check (removed from PHP as of v5.0) */
+
+if (!check_php_version(5)) {
+    // FIXME(?): Hmm, how do we distinguish between when an ini setting is
+    //           not available (ini_set() returns empty string) and when
+    //           the administrator set the value to an empty string?  The
+    //           latter is sure to be highly rare, so for now, just assume
+    //           that empty value means the setting isn't even available
+    //           (could also check PHP version when this setting was implemented)
+    //           although, we'll also warn the user if it is empty, with
+    //           a non-fatal error
+    $gpc_order = strtoupper(ini_get('gpc_order'));
+    if (empty($gpc_order))
+        do_err('Your gpc_order setting seems to be empty.  Make sure it is undefined in any PHP ini files, .htaccess files, etc. and not specifically set to an empty value or SquirrelMail may not function correctly', false);
+    else if (strpos($gpc_order, 'G') === FALSE
+     || strpos($gpc_order, 'P') === FALSE
+     || strpos($gpc_order, 'C') === FALSE) {
+        do_err('Your gpc_order setting is insufficient for SquirrelMail to function.  It needs to be set to "GPC", but you have it set to "' . htmlspecialchars($gpc_order) . '"', true);
+    } else {
+        echo $IND . "gpc_order OK: $gpc_order.<br />\n";
+    }
+}
+
+
 $php_exts = array('session','pcre');
 $diff = array_diff($php_exts, get_loaded_extensions());
 if(count($diff)) {
@@ -473,6 +528,3 @@ if(!empty($addrbook_dsn) || !empty($prefs_dsn) || !empty($addrbook_global_dsn))
 
 </body>
 </html>
-<?php
-// vim: et ts=4
-?>
