@@ -8,10 +8,13 @@
  *
  * @copyright &copy; 1999-2007 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: login.php 12352 2007-03-28 05:09:33Z jangliss $
+ * @version $Id: login.php 12614 2007-08-28 20:30:29Z pdontthink $
  * @package squirrelmail
  */
 
+/** This is the login page */
+define('PAGE_NAME', 'login');
+
 /**
  * Path for SquirrelMail required files.
  * @ignore
@@ -41,18 +44,29 @@ $base_uri = sqm_baseuri();
  * In case the last session was not terminated properly, make sure
  * we get a new one, but make sure we preserve session_expired_*
  */
+$sep = '';
+$sel = '';
+sqGetGlobalVar('session_expired_post', $sep, SQ_SESSION);
+sqGetGlobalVar('session_expired_location', $sel, SQ_SESSION);
 
-if ( !empty($_SESSION['session_expired_post']) && !empty($_SESSION['session_expired_location']) ) {
-    $sep = $_SESSION['session_expired_post'];
-    $sel = $_SESSION['session_expired_location'];
+/* blow away session */
+sqsession_destroy();
 
-    sqsession_destroy();
+/**
+ * in some rare instances, the session seems to stick
+ * around even after destroying it (!!), so if it does,
+ * we'll manually flatten the $_SESSION data
+ */
+if (!empty($_SESSION)) {
+    $_SESSION = array();
+}
 
-    sqsession_is_active();
-    sqsession_register($sep, 'session_expired_post');
+/* put session_expired_* variables back in session */
+sqsession_is_active();
+if (!empty($sel)) {
     sqsession_register($sel, 'session_expired_location');
-} else {
-    sqsession_destroy();
+    if (!empty($sep)) 
+        sqsession_register($sep, 'session_expired_post');
 }
 
 header('Pragma: no-cache');
@@ -154,7 +168,7 @@ echo html_tag( 'table',
                                 'right', '', 'width="30%"' ) .
                                 html_tag( 'td',
 				    addInput($username_form_name, $loginname_value),
-                                'left', '', 'width="*"' )
+                                'left', '', 'width="70%"' )
                                 ) . "\n" .
                             html_tag( 'tr',
                                 html_tag( 'td',
@@ -165,7 +179,7 @@ echo html_tag( 'table',
 				    addHidden('js_autodetect_results', SMPREF_JS_OFF).
                     $mailtofield . 
 				    addHidden('just_logged_in', '1'),
-                                'left', '', 'width="*"' )
+                                'left', '', 'width="70%"' )
                             ) ,
                         'center', $color[4], 'border="0" width="100%"' ) ,
                     'left',$color[4] )
